require "uri"

module Apcera
  class ProvidersApi
    attr_accessor :api_client

    def initialize(api_client = nil)
      @api_client = api_client || Configuration.api_client
    end

    # Returns a list of providers defined on the cluster.
    # Returns a list of providers defined on the cluster.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [Array<Provider>]
    def providers_get(opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: ProvidersApi#providers_get ..."
      end
      
      
      # resource path
      path = "/providers".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      result = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Array<Provider>')
      if Configuration.debugging
        Configuration.logger.debug "API called: ProvidersApi#providers_get. Result: #{result.inspect}"
      end
      return result
    end

    # Creates a new provider.
    # Creates a new provider.
    # @param job An object that defines the properties of the new provider.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [Array<Provider>]
    def providers_post(job, opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: ProvidersApi#providers_post ..."
      end
      
      
      # verify the required parameter 'job' is set
      fail "Missing the required parameter 'job' when calling providers_post" if job.nil?
      
      # resource path
      path = "/providers".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = @api_client.object_to_http_body(job)
      

      auth_names = ['authorization']
      result = @api_client.call_api(:POST, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Array<Provider>')
      if Configuration.debugging
        Configuration.logger.debug "API called: ProvidersApi#providers_post. Result: #{result.inspect}"
      end
      return result
    end

    # Deletes the specified provider.
    # Deletes the specified provider.
    # @param uuid UUID of the provider to delete.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [nil]
    def providers_uuid_delete(uuid, opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: ProvidersApi#providers_uuid_delete ..."
      end
      
      
      # verify the required parameter 'uuid' is set
      fail "Missing the required parameter 'uuid' when calling providers_uuid_delete" if uuid.nil?
      
      # resource path
      path = "/providers/{uuid}".sub('{format}','json').sub('{' + 'uuid' + '}', uuid.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      @api_client.call_api(:DELETE, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names)
      if Configuration.debugging
        Configuration.logger.debug "API called: ProvidersApi#providers_uuid_delete"
      end
      return nil
    end
  end
end




