require "uri"

module Apcera
  class UtilitiesApi
    attr_accessor :api_client

    def initialize(api_client = nil)
      @api_client = api_client || Configuration.api_client
    end

    # Returns information about the API server.
    # Returns information about the API server.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [Info]
    def info_get(opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: UtilitiesApi#info_get ..."
      end
      
      
      # resource path
      path = "/info".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      result = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Info')
      if Configuration.debugging
        Configuration.logger.debug "API called: UtilitiesApi#info_get. Result: #{result.inspect}"
      end
      return result
    end

    # Returns the default namespace for the currently logged-in user.
    # Returns the default namespace for the currently logged-in user.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [Namespace]
    def namespace_default_get(opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: UtilitiesApi#namespace_default_get ..."
      end
      
      
      # resource path
      path = "/namespace/default".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      result = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Namespace')
      if Configuration.debugging
        Configuration.logger.debug "API called: UtilitiesApi#namespace_default_get. Result: #{result.inspect}"
      end
      return result
    end

    # Lists supported workload runtimes.
    # Lists file names and patterns used by APC to determine the appropriate staging pipeline to stage a given workload.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [Array<Runtime>]
    def runtimes_get(opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: UtilitiesApi#runtimes_get ..."
      end
      
      
      # resource path
      path = "/runtimes".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      result = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Array<Runtime>')
      if Configuration.debugging
        Configuration.logger.debug "API called: UtilitiesApi#runtimes_get. Result: #{result.inspect}"
      end
      return result
    end

    # Returns Apcera cluster version information and APC download links.
    # Returns Apcera cluster version information, and links to download compatible versions of APC for supported platforms.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :authorization 
    # @return [VersionInfo]
    def version_get(opts = {})
    
      if Configuration.debugging
        Configuration.logger.debug "Calling API: UtilitiesApi#version_get ..."
      end
      
      
      # resource path
      path = "/version".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)
      header_params[:'authorization'] = opts[:'authorization'] if opts[:'authorization']

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['authorization']
      result = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'VersionInfo')
      if Configuration.debugging
        Configuration.logger.debug "API called: UtilitiesApi#version_get. Result: #{result.inspect}"
      end
      return result
    end
  end
end




