module Apcera
  # 
  class Package < BaseObject
    attr_accessor :created_at, :created_by, :dependencies, :environment, :error_message, :fqn, :name, :provides, :resource, :resources, :staging_pipeline, :staging_pipeline_fqn, :state, :tags, :updated_at, :updated_by, :uuid, :version_id
    # attribute mapping from ruby-style variable name to JSON key
    def self.attribute_map
      {
        
        # The date and time when the package was created.
        :'created_at' => :'created_at',
        
        # Principal name of the user who created the package.
        :'created_by' => :'created_by',
        
        # List of dependencies that the package has in order to be used. A dependency expresses a requirement that a package has on an other package.
        :'dependencies' => :'dependencies',
        
        # List of environment variables that are added to any process that uses the package.
        :'environment' => :'environment',
        
        # Error encountered during an asynchronous operation on the package. An example is a failure encountered during instance snapshot; the ErrorMessage field on the created snapshot package would contain more information.
        :'error_message' => :'error_message',
        
        # Package&#39;s fully-qualified name.
        :'fqn' => :'fqn',
        
        # Package name.
        :'name' => :'name',
        
        # List of &#39;provides&#39; that the package provides for other packages to use. A &#39;provide&#39; expresses a named resource that other packages or jobs can add as a dependency.
        :'provides' => :'provides',
        
        # Deprecated. Use `resources`. An object that describes the package&#39;s associated binary resource.
        :'resource' => :'resource',
        
        # An list of objects that describes the package&#39;s associated binary resources.
        :'resources' => :'resources',
        
        # The UUID of the staging pipeline used to stage this package into a runnable state.
        :'staging_pipeline' => :'staging_pipeline',
        
        # The fully-qualified name of the staging pipeline used to stage the package.
        :'staging_pipeline_fqn' => :'staging_pipeline_fqn',
        
        # Package state. Possible values are `uploading`, &#39;staging`, `failed`, `ready`, `deleted`, and `unknown`.
        :'state' => :'state',
        
        # Map of tags by tag name.
        :'tags' => :'tags',
        
        # The date and time when the package was most recently updated.
        :'updated_at' => :'updated_at',
        
        # Principal name of the last user to update the package.
        :'updated_by' => :'updated_by',
        
        # The package&#39;s unique identifier.
        :'uuid' => :'uuid',
        
        # Package&#39;s auto-incremented version number.
        :'version_id' => :'version_id'
        
      }
    end

    # attribute type
    def self.swagger_types
      {
        :'created_at' => :'DateTime',
        :'created_by' => :'String',
        :'dependencies' => :'Array<Dependency>',
        :'environment' => :'Hash<String, String>',
        :'error_message' => :'String',
        :'fqn' => :'String',
        :'name' => :'String',
        :'provides' => :'Array<Provide>',
        :'resource' => :'PackageResource',
        :'resources' => :'Array<PackageResource>',
        :'staging_pipeline' => :'String',
        :'staging_pipeline_fqn' => :'String',
        :'state' => :'String',
        :'tags' => :'Hash<String, String>',
        :'updated_at' => :'DateTime',
        :'updated_by' => :'String',
        :'uuid' => :'String',
        :'version_id' => :'Integer'
        
      }
    end

    def initialize(attributes = {})
      return if !attributes.is_a?(Hash) || attributes.empty?

      # convert string to symbol for hash key
      attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

      
      if attributes[:'created_at']
        self.created_at = attributes[:'created_at']
      end
      
      if attributes[:'created_by']
        self.created_by = attributes[:'created_by']
      end
      
      if attributes[:'dependencies']
        if (value = attributes[:'dependencies']).is_a?(Array)
          self.dependencies = value
        end
      end
      
      if attributes[:'environment']
        if (value = attributes[:'environment']).is_a?(Array)
          self.environment = value
        end
      end
      
      if attributes[:'error_message']
        self.error_message = attributes[:'error_message']
      end
      
      if attributes[:'fqn']
        self.fqn = attributes[:'fqn']
      end
      
      if attributes[:'name']
        self.name = attributes[:'name']
      end
      
      if attributes[:'provides']
        if (value = attributes[:'provides']).is_a?(Array)
          self.provides = value
        end
      end
      
      if attributes[:'resource']
        self.resource = attributes[:'resource']
      end
      
      if attributes[:'resources']
        if (value = attributes[:'resources']).is_a?(Array)
          self.resources = value
        end
      end
      
      if attributes[:'staging_pipeline']
        self.staging_pipeline = attributes[:'staging_pipeline']
      end
      
      if attributes[:'staging_pipeline_fqn']
        self.staging_pipeline_fqn = attributes[:'staging_pipeline_fqn']
      end
      
      if attributes[:'state']
        self.state = attributes[:'state']
      end
      
      if attributes[:'tags']
        if (value = attributes[:'tags']).is_a?(Array)
          self.tags = value
        end
      end
      
      if attributes[:'updated_at']
        self.updated_at = attributes[:'updated_at']
      end
      
      if attributes[:'updated_by']
        self.updated_by = attributes[:'updated_by']
      end
      
      if attributes[:'uuid']
        self.uuid = attributes[:'uuid']
      end
      
      if attributes[:'version_id']
        self.version_id = attributes[:'version_id']
      end
      
    end

  end
end
